==> plasma_2.5.2.tar.gz: plasma_2.5.2/docs/doxygen/out/html/group__PLASMA__Complex64__t.js <==
var group__PLASMA__Complex64__t =
[
    [ "PLASMA_zcgels", "group__PLASMA__Complex64__t_ga6733ad2b79f186348ba47778e2e26fae.html#ga6733ad2b79f186348ba47778e2e26fae", null ],
    [ "PLASMA_zcgesv", "group__PLASMA__Complex64__t_gab372ccb64517ddb8e0f7ea66088489a9.html#gab372ccb64517ddb8e0f7ea66088489a9", null ],
    [ "PLASMA_zcposv", "group__PLASMA__Complex64__t_ga11ee4c71901e8675d5423cfceecaaf43.html#ga11ee4c71901e8675d5423cfceecaaf43", null ],
    [ "PLASMA_zcungesv", "group__PLASMA__Complex64__t_gaba15b4f438d8d2fe41f2c38820d043ef.html#gaba15b4f438d8d2fe41f2c38820d043ef", null ],
    [ "PLASMA_zgebrd", "group__PLASMA__Complex64__t_ga1d3eeb613fb6212be5c52cbde1dbf8d3.html#ga1d3eeb613fb6212be5c52cbde1dbf8d3", null ],
    [ "PLASMA_zgecon", "group__PLASMA__Complex64__t_gace89692c6f34773c9daad5f35610e95b.html#gace89692c6f34773c9daad5f35610e95b", null ],
    [ "PLASMA_zgelqf", "group__PLASMA__Complex64__t_ga8990facf0cb04df2a107c02e5dd5f3f7.html#ga8990facf0cb04df2a107c02e5dd5f3f7", null ],
    [ "PLASMA_zgelqs", "group__PLASMA__Complex64__t_ga8e8b7d834eb0ad99766799bcfa48d4b1.html#ga8e8b7d834eb0ad99766799bcfa48d4b1", null ],
    [ "PLASMA_zgels", "group__PLASMA__Complex64__t_ga37e31dd7208585a1720db61e38e31a55.html#ga37e31dd7208585a1720db61e38e31a55", null ],
    [ "PLASMA_zgemm", "group__PLASMA__Complex64__t_ga1a0f8d759e535f9947ae11baa0af6fa3.html#ga1a0f8d759e535f9947ae11baa0af6fa3", null ],
    [ "PLASMA_zgeqp3", "group__PLASMA__Complex64__t_ga8c6ffd25fb20c4c7398133141910a8a6.html#ga8c6ffd25fb20c4c7398133141910a8a6", null ],
    [ "PLASMA_zgeqrf", "group__PLASMA__Complex64__t_ga9d4fae8697b364c384faa7480aea3118.html#ga9d4fae8697b364c384faa7480aea3118", null ],
    [ "PLASMA_zgeqrs", "group__PLASMA__Complex64__t_gaaded5cbc1a55a5d1cc6a231b8da07bf0.html#gaaded5cbc1a55a5d1cc6a231b8da07bf0", null ],
    [ "PLASMA_zgesdd", "group__PLASMA__Complex64__t_ga4550f69e64e28c5b19e82345a4c4fad0.html#ga4550f69e64e28c5b19e82345a4c4fad0", null ],
    [ "PLASMA_zgesv", "group__PLASMA__Complex64__t_ga94397d6fba523c946f1e56cfe9aa967d.html#ga94397d6fba523c946f1e56cfe9aa967d", null ],
    [ "PLASMA_zgesv_incpiv", "group__PLASMA__Complex64__t_ga27916109c8ac4bed6d101fcb98b27fad.html#ga27916109c8ac4bed6d101fcb98b27fad", null ],
    [ "PLASMA_zgesvd", "group__PLASMA__Complex64__t_ga947d0b69e1be45578bb8b869ac06b963.html#ga947d0b69e1be45578bb8b869ac06b963", null ],
    [ "PLASMA_zgetrf", "group__PLASMA__Complex64__t_ga03449aa4e83b2f2223dad281d122697d.html#ga03449aa4e83b2f2223dad281d122697d", null ],
    [ "PLASMA_zgetrf_incpiv", "group__PLASMA__Complex64__t_ga085b5e62180512c7c603e72a9092ad8d.html#ga085b5e62180512c7c603e72a9092ad8d", null ],
    [ "PLASMA_zgetrf_nopiv", "group__PLASMA__Complex64__t_ga6fddd4132db9c55950061ff61f1e00e0.html#ga6fddd4132db9c55950061ff61f1e00e0", null ],
    [ "PLASMA_zgetrf_tntpiv", "group__PLASMA__Complex64__t_ga9ab8aca11b7dadc50bcb9dea67cd4954.html#ga9ab8aca11b7dadc50bcb9dea67cd4954", null ],
    [ "PLASMA_zgetri", "group__PLASMA__Complex64__t_ga96b45d431296d17561924b09a770ce17.html#ga96b45d431296d17561924b09a770ce17", null ],
    [ "PLASMA_zgetrs", "group__PLASMA__Complex64__t_gaf035432f37a7fd4cf2263d1eccaa89a5.html#gaf035432f37a7fd4cf2263d1eccaa89a5", null ],
    [ "PLASMA_zgetrs_incpiv", "group__PLASMA__Complex64__t_ga3af09862f7bf51c6f41e5220859f802d.html#ga3af09862f7bf51c6f41e5220859f802d", null ],
    [ "PLASMA_zheev", "group__PLASMA__Complex64__t_gad148e141c13feede49709370caea9c2a.html#gad148e141c13feede49709370caea9c2a", null ],
    [ "PLASMA_zheevd", "group__PLASMA__Complex64__t_gad7de537e69c66566cc4e8e0b9fbfdb87.html#gad7de537e69c66566cc4e8e0b9fbfdb87", null ],
    [ "PLASMA_zheevr", "group__PLASMA__Complex64__t_ga4658f650ae51fd533d3f2406b25aa70d.html#ga4658f650ae51fd533d3f2406b25aa70d", null ],
    [ "PLASMA_zhegst", "group__PLASMA__Complex64__t_ga387eb7a21f8b3d03aec26324255e7510.html#ga387eb7a21f8b3d03aec26324255e7510", null ],
    [ "PLASMA_zhegv", "group__PLASMA__Complex64__t_gaec004491cb00c99f63f9604c84ef8f43.html#gaec004491cb00c99f63f9604c84ef8f43", null ],
    [ "PLASMA_zhegvd", "group__PLASMA__Complex64__t_ga6ee549df75bf7738aa6066c564ff72a9.html#ga6ee549df75bf7738aa6066c564ff72a9", null ],
    [ "PLASMA_zhemm", "group__PLASMA__Complex64__t_gad53a9ae69e0ff46c3859f19c16b97081.html#gad53a9ae69e0ff46c3859f19c16b97081", null ],
    [ "PLASMA_zher2k", "group__PLASMA__Complex64__t_ga1086284f7bd6db0de2341eeaa3a3e655.html#ga1086284f7bd6db0de2341eeaa3a3e655", null ],
    [ "PLASMA_zherk", "group__PLASMA__Complex64__t_ga37897923ff4fb613bbd5a69a58b12fb8.html#ga37897923ff4fb613bbd5a69a58b12fb8", null ],
    [ "PLASMA_zhetrd", "group__PLASMA__Complex64__t_gadeaa16b417f2033a10685c130db081fb.html#gadeaa16b417f2033a10685c130db081fb", null ],
    [ "PLASMA_zlacpy", "group__PLASMA__Complex64__t_ga8502c982b63153d2a7c11c05fe51cd39.html#ga8502c982b63153d2a7c11c05fe51cd39", null ],
    [ "PLASMA_zlange", "group__PLASMA__Complex64__t_ga0a59419c4731f28c9d8ff470d23d5db3.html#ga0a59419c4731f28c9d8ff470d23d5db3", null ],
    [ "PLASMA_zlanhe", "group__PLASMA__Complex64__t_ga58656cfce8c3d31d5efcf3e987e33e64.html#ga58656cfce8c3d31d5efcf3e987e33e64", null ],
    [ "PLASMA_zlansy", "group__PLASMA__Complex64__t_ga2e163a7890571e447804ed020a4c05b5.html#ga2e163a7890571e447804ed020a4c05b5", null ],
    [ "PLASMA_zLapack_to_Tile", "group__PLASMA__Complex64__t_ga54817e0733e678bcdfdfeaa76ab486f6.html#ga54817e0733e678bcdfdfeaa76ab486f6", null ],
    [ "PLASMA_zlaset", "group__PLASMA__Complex64__t_gad41de0032d2290e448cfc67683dc01bb.html#gad41de0032d2290e448cfc67683dc01bb", null ],
    [ "PLASMA_zlaswp", "group__PLASMA__Complex64__t_gacc6ccd85efa0bbc451731b0ba5a1d11a.html#gacc6ccd85efa0bbc451731b0ba5a1d11a", null ],
    [ "PLASMA_zlaswpc", "group__PLASMA__Complex64__t_gaad7e6621e986a380618b84cd67359d7c.html#gaad7e6621e986a380618b84cd67359d7c", null ],
    [ "PLASMA_zlauum", "group__PLASMA__Complex64__t_ga0e1f064db19e3855c590172274fbdf43.html#ga0e1f064db19e3855c590172274fbdf43", null ],
    [ "PLASMA_zplghe", "group__PLASMA__Complex64__t_ga3a50559a69450b4f13a23c4af092c60e.html#ga3a50559a69450b4f13a23c4af092c60e", null ],
    [ "PLASMA_zplgsy", "group__PLASMA__Complex64__t_ga065c2bc2190fc079035e1de4d16e4e60.html#ga065c2bc2190fc079035e1de4d16e4e60", null ],
    [ "PLASMA_zplrnt", "group__PLASMA__Complex64__t_gaed78cffc7c2835c485ef7c8e3761d127.html#gaed78cffc7c2835c485ef7c8e3761d127", null ],
    [ "PLASMA_zpocon", "group__PLASMA__Complex64__t_ga52f6ee7a56e26b17f1d9fbb421156688.html#ga52f6ee7a56e26b17f1d9fbb421156688", null ],
    [ "PLASMA_zposv", "group__PLASMA__Complex64__t_gaed71622155778ea4372e34879184e742.html#gaed71622155778ea4372e34879184e742", null ],
    [ "PLASMA_zpotrf", "group__PLASMA__Complex64__t_ga850a6c9da7c5632d160b28f211cdf2eb.html#ga850a6c9da7c5632d160b28f211cdf2eb", null ],
    [ "PLASMA_zpotri", "group__PLASMA__Complex64__t_ga6dd563144dd8c7f29a58659f220f44a0.html#ga6dd563144dd8c7f29a58659f220f44a0", null ],
    [ "PLASMA_zpotrs", "group__PLASMA__Complex64__t_gafa3392d835a508f57674c601c46eb331.html#gafa3392d835a508f57674c601c46eb331", null ],
    [ "PLASMA_zsymm", "group__PLASMA__Complex64__t_ga78d0974b51b7d019e0606422b3292b46.html#ga78d0974b51b7d019e0606422b3292b46", null ],
    [ "PLASMA_zsyr2k", "group__PLASMA__Complex64__t_ga575230c6f1629fabf7ba151a09e4c7a7.html#ga575230c6f1629fabf7ba151a09e4c7a7", null ],
    [ "PLASMA_zsyrk", "group__PLASMA__Complex64__t_gaae2f934da463e7256c82500587c3042b.html#gaae2f934da463e7256c82500587c3042b", null ],
    [ "PLASMA_zTile_to_Lapack", "group__PLASMA__Complex64__t_ga8df0b9fdc5537a648d7544b528c9e6e3.html#ga8df0b9fdc5537a648d7544b528c9e6e3", null ],
    [ "PLASMA_ztrmm", "group__PLASMA__Complex64__t_ga9d25baa9dfdb84cd69270558338ce9b1.html#ga9d25baa9dfdb84cd69270558338ce9b1", null ],
    [ "PLASMA_ztrsm", "group__PLASMA__Complex64__t_ga36cf60d55716c7ab0c2fba7fb8833e2c.html#ga36cf60d55716c7ab0c2fba7fb8833e2c", null ],
    [ "PLASMA_ztrsmpl", "group__PLASMA__Complex64__t_gac8d8e79226587e10e5dc5fddae448769.html#gac8d8e79226587e10e5dc5fddae448769", null ],
    [ "PLASMA_ztrsmrv", "group__PLASMA__Complex64__t_gadc613ba744f045286d0869bbbf6765ac.html#gadc613ba744f045286d0869bbbf6765ac", null ],
    [ "PLASMA_ztrtri", "group__PLASMA__Complex64__t_gaf634d0dec7f2b59a571b5aafa19892d1.html#gaf634d0dec7f2b59a571b5aafa19892d1", null ],
    [ "PLASMA_zunglq", "group__PLASMA__Complex64__t_ga8d2c7940bdd249a0a1e633b0ac6d107c.html#ga8d2c7940bdd249a0a1e633b0ac6d107c", null ],
    [ "PLASMA_zungqr", "group__PLASMA__Complex64__t_gafedf859d9373a2738b24e5780360ec5b.html#gafedf859d9373a2738b24e5780360ec5b", null ],
    [ "PLASMA_zunmlq", "group__PLASMA__Complex64__t_ga2c015740671fa101298fb9841b25f5d2.html#ga2c015740671fa101298fb9841b25f5d2", null ],
    [ "PLASMA_zunmqr", "group__PLASMA__Complex64__t_ga2a00379e9ae15c89c8a21d7dfa945e8f.html#ga2a00379e9ae15c89c8a21d7dfa945e8f", null ]
];

==> plasma_2.6.0.tar.gz: plasma_2.6.0/docs/doxygen/out/html/group__PLASMA__Complex64__t.js <==
var group__PLASMA__Complex64__t =
[
    [ "PLASMA_zcgels", "group__PLASMA__Complex64__t_ga6733ad2b79f186348ba47778e2e26fae.html#ga6733ad2b79f186348ba47778e2e26fae", null ],
    [ "PLASMA_zcgesv", "group__PLASMA__Complex64__t_gab372ccb64517ddb8e0f7ea66088489a9.html#gab372ccb64517ddb8e0f7ea66088489a9", null ],
    [ "PLASMA_zcposv", "group__PLASMA__Complex64__t_ga11ee4c71901e8675d5423cfceecaaf43.html#ga11ee4c71901e8675d5423cfceecaaf43", null ],
    [ "PLASMA_zcungesv", "group__PLASMA__Complex64__t_gaba15b4f438d8d2fe41f2c38820d043ef.html#gaba15b4f438d8d2fe41f2c38820d043ef", null ],
    [ "PLASMA_zgebrd", "group__PLASMA__Complex64__t_ga1d3eeb613fb6212be5c52cbde1dbf8d3.html#ga1d3eeb613fb6212be5c52cbde1dbf8d3", null ],
    [ "PLASMA_zgecon", "group__PLASMA__Complex64__t_gace89692c6f34773c9daad5f35610e95b.html#gace89692c6f34773c9daad5f35610e95b", null ],
    [ "PLASMA_zgelqf", "group__PLASMA__Complex64__t_ga8990facf0cb04df2a107c02e5dd5f3f7.html#ga8990facf0cb04df2a107c02e5dd5f3f7", null ],
    [ "PLASMA_zgelqs", "group__PLASMA__Complex64__t_ga8e8b7d834eb0ad99766799bcfa48d4b1.html#ga8e8b7d834eb0ad99766799bcfa48d4b1", null ],
    [ "PLASMA_zgels", "group__PLASMA__Complex64__t_ga37e31dd7208585a1720db61e38e31a55.html#ga37e31dd7208585a1720db61e38e31a55", null ],
    [ "PLASMA_zgemm", "group__PLASMA__Complex64__t_ga1a0f8d759e535f9947ae11baa0af6fa3.html#ga1a0f8d759e535f9947ae11baa0af6fa3", null ],
    [ "PLASMA_zgeqp3", "group__PLASMA__Complex64__t_ga8c6ffd25fb20c4c7398133141910a8a6.html#ga8c6ffd25fb20c4c7398133141910a8a6", null ],
    [ "PLASMA_zgeqrf", "group__PLASMA__Complex64__t_ga9d4fae8697b364c384faa7480aea3118.html#ga9d4fae8697b364c384faa7480aea3118", null ],
    [ "PLASMA_zgeqrs", "group__PLASMA__Complex64__t_gaaded5cbc1a55a5d1cc6a231b8da07bf0.html#gaaded5cbc1a55a5d1cc6a231b8da07bf0", null ],
    [ "PLASMA_zgesdd", "group__PLASMA__Complex64__t_ga4550f69e64e28c5b19e82345a4c4fad0.html#ga4550f69e64e28c5b19e82345a4c4fad0", null ],
    [ "PLASMA_zgesv", "group__PLASMA__Complex64__t_ga94397d6fba523c946f1e56cfe9aa967d.html#ga94397d6fba523c946f1e56cfe9aa967d", null ],
    [ "PLASMA_zgesv_incpiv", "group__PLASMA__Complex64__t_ga27916109c8ac4bed6d101fcb98b27fad.html#ga27916109c8ac4bed6d101fcb98b27fad", null ],
    [ "PLASMA_zgesvd", "group__PLASMA__Complex64__t_ga947d0b69e1be45578bb8b869ac06b963.html#ga947d0b69e1be45578bb8b869ac06b963", null ],
    [ "PLASMA_zgetrf", "group__PLASMA__Complex64__t_ga03449aa4e83b2f2223dad281d122697d.html#ga03449aa4e83b2f2223dad281d122697d", null ],
    [ "PLASMA_zgetrf_incpiv", "group__PLASMA__Complex64__t_ga085b5e62180512c7c603e72a9092ad8d.html#ga085b5e62180512c7c603e72a9092ad8d", null ],
    [ "PLASMA_zgetrf_nopiv", "group__PLASMA__Complex64__t_ga6fddd4132db9c55950061ff61f1e00e0.html#ga6fddd4132db9c55950061ff61f1e00e0", null ],
    [ "PLASMA_zgetrf_tntpiv", "group__PLASMA__Complex64__t_ga9ab8aca11b7dadc50bcb9dea67cd4954.html#ga9ab8aca11b7dadc50bcb9dea67cd4954", null ],
    [ "PLASMA_zgetri", "group__PLASMA__Complex64__t_ga96b45d431296d17561924b09a770ce17.html#ga96b45d431296d17561924b09a770ce17", null ],
    [ "PLASMA_zgetrs", "group__PLASMA__Complex64__t_gaf035432f37a7fd4cf2263d1eccaa89a5.html#gaf035432f37a7fd4cf2263d1eccaa89a5", null ],
    [ "PLASMA_zgetrs_incpiv", "group__PLASMA__Complex64__t_ga3af09862f7bf51c6f41e5220859f802d.html#ga3af09862f7bf51c6f41e5220859f802d", null ],
    [ "PLASMA_zheev", "group__PLASMA__Complex64__t_gad148e141c13feede49709370caea9c2a.html#gad148e141c13feede49709370caea9c2a", null ],
    [ "PLASMA_zheevd", "group__PLASMA__Complex64__t_gad7de537e69c66566cc4e8e0b9fbfdb87.html#gad7de537e69c66566cc4e8e0b9fbfdb87", null ],
    [ "PLASMA_zheevr", "group__PLASMA__Complex64__t_ga4658f650ae51fd533d3f2406b25aa70d.html#ga4658f650ae51fd533d3f2406b25aa70d", null ],
    [ "PLASMA_zhegst", "group__PLASMA__Complex64__t_ga387eb7a21f8b3d03aec26324255e7510.html#ga387eb7a21f8b3d03aec26324255e7510", null ],
    [ "PLASMA_zhegv", "group__PLASMA__Complex64__t_gaec004491cb00c99f63f9604c84ef8f43.html#gaec004491cb00c99f63f9604c84ef8f43", null ],
    [ "PLASMA_zhegvd", "group__PLASMA__Complex64__t_ga6ee549df75bf7738aa6066c564ff72a9.html#ga6ee549df75bf7738aa6066c564ff72a9", null ],
    [ "PLASMA_zhemm", "group__PLASMA__Complex64__t_gad53a9ae69e0ff46c3859f19c16b97081.html#gad53a9ae69e0ff46c3859f19c16b97081", null ],
    [ "PLASMA_zher2k", "group__PLASMA__Complex64__t_ga1086284f7bd6db0de2341eeaa3a3e655.html#ga1086284f7bd6db0de2341eeaa3a3e655", null ],
    [ "PLASMA_zherk", "group__PLASMA__Complex64__t_ga37897923ff4fb613bbd5a69a58b12fb8.html#ga37897923ff4fb613bbd5a69a58b12fb8", null ],
    [ "PLASMA_zhetrd", "group__PLASMA__Complex64__t_gadeaa16b417f2033a10685c130db081fb.html#gadeaa16b417f2033a10685c130db081fb", null ],
    [ "PLASMA_zlacpy", "group__PLASMA__Complex64__t_ga8502c982b63153d2a7c11c05fe51cd39.html#ga8502c982b63153d2a7c11c05fe51cd39", null ],
    [ "PLASMA_zlange", "group__PLASMA__Complex64__t_ga0a59419c4731f28c9d8ff470d23d5db3.html#ga0a59419c4731f28c9d8ff470d23d5db3", null ],
    [ "PLASMA_zlanhe", "group__PLASMA__Complex64__t_ga58656cfce8c3d31d5efcf3e987e33e64.html#ga58656cfce8c3d31d5efcf3e987e33e64", null ],
    [ "PLASMA_zlansy", "group__PLASMA__Complex64__t_ga2e163a7890571e447804ed020a4c05b5.html#ga2e163a7890571e447804ed020a4c05b5", null ],
    [ "PLASMA_zlantr", "group__PLASMA__Complex64__t_ga34d019535c07ecb781380648bb92ce1c.html#ga34d019535c07ecb781380648bb92ce1c", null ],
    [ "PLASMA_zLapack_to_Tile", "group__PLASMA__Complex64__t_ga54817e0733e678bcdfdfeaa76ab486f6.html#ga54817e0733e678bcdfdfeaa76ab486f6", null ],
    [ "PLASMA_zlaset", "group__PLASMA__Complex64__t_gad41de0032d2290e448cfc67683dc01bb.html#gad41de0032d2290e448cfc67683dc01bb", null ],
    [ "PLASMA_zlaswp", "group__PLASMA__Complex64__t_gacc6ccd85efa0bbc451731b0ba5a1d11a.html#gacc6ccd85efa0bbc451731b0ba5a1d11a", null ],
    [ "PLASMA_zlaswpc", "group__PLASMA__Complex64__t_gaad7e6621e986a380618b84cd67359d7c.html#gaad7e6621e986a380618b84cd67359d7c", null ],
    [ "PLASMA_zlauum", "group__PLASMA__Complex64__t_ga0e1f064db19e3855c590172274fbdf43.html#ga0e1f064db19e3855c590172274fbdf43", null ],
    [ "PLASMA_zplghe", "group__PLASMA__Complex64__t_ga3a50559a69450b4f13a23c4af092c60e.html#ga3a50559a69450b4f13a23c4af092c60e", null ],
    [ "PLASMA_zplgsy", "group__PLASMA__Complex64__t_ga065c2bc2190fc079035e1de4d16e4e60.html#ga065c2bc2190fc079035e1de4d16e4e60", null ],
    [ "PLASMA_zplrnt", "group__PLASMA__Complex64__t_gaed78cffc7c2835c485ef7c8e3761d127.html#gaed78cffc7c2835c485ef7c8e3761d127", null ],
    [ "PLASMA_zpltmg", "group__PLASMA__Complex64__t_ga0c1fc92152972274a3f2c7d482ccd365.html#ga0c1fc92152972274a3f2c7d482ccd365", null ],
    [ "PLASMA_zpocon", "group__PLASMA__Complex64__t_ga52f6ee7a56e26b17f1d9fbb421156688.html#ga52f6ee7a56e26b17f1d9fbb421156688", null ],
    [ "PLASMA_zposv", "group__PLASMA__Complex64__t_gaed71622155778ea4372e34879184e742.html#gaed71622155778ea4372e34879184e742", null ],
    [ "PLASMA_zpotrf", "group__PLASMA__Complex64__t_ga850a6c9da7c5632d160b28f211cdf2eb.html#ga850a6c9da7c5632d160b28f211cdf2eb", null ],
    [ "PLASMA_zpotri", "group__PLASMA__Complex64__t_ga6dd563144dd8c7f29a58659f220f44a0.html#ga6dd563144dd8c7f29a58659f220f44a0", null ],
    [ "PLASMA_zpotrs", "group__PLASMA__Complex64__t_gafa3392d835a508f57674c601c46eb331.html#gafa3392d835a508f57674c601c46eb331", null ],
    [ "PLASMA_zsymm", "group__PLASMA__Complex64__t_ga78d0974b51b7d019e0606422b3292b46.html#ga78d0974b51b7d019e0606422b3292b46", null ],
    [ "PLASMA_zsyr2k", "group__PLASMA__Complex64__t_ga575230c6f1629fabf7ba151a09e4c7a7.html#ga575230c6f1629fabf7ba151a09e4c7a7", null ],
    [ "PLASMA_zsyrk", "group__PLASMA__Complex64__t_gaae2f934da463e7256c82500587c3042b.html#gaae2f934da463e7256c82500587c3042b", null ],
    [ "PLASMA_zTile_to_Lapack", "group__PLASMA__Complex64__t_ga8df0b9fdc5537a648d7544b528c9e6e3.html#ga8df0b9fdc5537a648d7544b528c9e6e3", null ],
    [ "PLASMA_ztrmm", "group__PLASMA__Complex64__t_ga9d25baa9dfdb84cd69270558338ce9b1.html#ga9d25baa9dfdb84cd69270558338ce9b1", null ],
    [ "PLASMA_ztrsm", "group__PLASMA__Complex64__t_ga36cf60d55716c7ab0c2fba7fb8833e2c.html#ga36cf60d55716c7ab0c2fba7fb8833e2c", null ],
    [ "PLASMA_ztrsmpl", "group__PLASMA__Complex64__t_gac8d8e79226587e10e5dc5fddae448769.html#gac8d8e79226587e10e5dc5fddae448769", null ],
    [ "PLASMA_ztrsmrv", "group__PLASMA__Complex64__t_gadc613ba744f045286d0869bbbf6765ac.html#gadc613ba744f045286d0869bbbf6765ac", null ],
    [ "PLASMA_ztrtri", "group__PLASMA__Complex64__t_gaf634d0dec7f2b59a571b5aafa19892d1.html#gaf634d0dec7f2b59a571b5aafa19892d1", null ],
    [ "PLASMA_zunglq", "group__PLASMA__Complex64__t_ga8d2c7940bdd249a0a1e633b0ac6d107c.html#ga8d2c7940bdd249a0a1e633b0ac6d107c", null ],
    [ "PLASMA_zungqr", "group__PLASMA__Complex64__t_gafedf859d9373a2738b24e5780360ec5b.html#gafedf859d9373a2738b24e5780360ec5b", null ],
    [ "PLASMA_zunmlq", "group__PLASMA__Complex64__t_ga2c015740671fa101298fb9841b25f5d2.html#ga2c015740671fa101298fb9841b25f5d2", null ],
    [ "PLASMA_zunmqr", "group__PLASMA__Complex64__t_ga2a00379e9ae15c89c8a21d7dfa945e8f.html#ga2a00379e9ae15c89c8a21d7dfa945e8f", null ]
];
